@@ -32,14 +32,14 @@
 #' child nodes with a state equivalent to the ancestral node will remain in the polytomy, while more primitive
 #' or more derived states will be sorted into their own separate ladders composed of paraphyletic groups, ordered
 #' so to move 'away' state-by-state from the ancestral node's inferred character state.
-#' This option is not applicable if \code{type = "ACCTRAN"}, as cost matrices cannot
-#' be used with ACCTRAN in \code{ancestral.pars}, and an error will be returned if \code{orderedChar=TRUE} but
-#' a cost matrix is given manually.
+# This option is not applicable if \code{type = "ACCTRAN"}, as cost matrices cannot
+# be used with ACCTRAN in \code{ancestral.pars}, and an error will be returned if \code{orderedChar=TRUE} but
+# a cost matrix is given manually.
 
 #' @param stateBias This argument controls how \code{resolveTreeChar} handles ancestral node reconstructions that have
 #' multiple states competing for the maximum weight of any state (i.e. if states 0 and 1 both have 0.4 of the weight). The
 #' default, where \code{stateBias = NULL} causes uncertainty at nodes among states to be treated as a single 'group' identical
-#' to any states within it. Essentially, this means that for the example polytomy where the ancestor hax maximum weight for both 0 and 1, 
+#' to any states within it. Essentially, this means that for the example polytomy where the ancestor has maximum weight for both 0 and 1, 
 #' any child nodes with 0, 1 or both of these states will be considered to have an identical state for the purpose of grouping nodes
 #' for the purpose of further resolving polytomies. If and only if \code{orderedChar = TRUE}, then additional options of
 #' \code{stateBias = 'primitive'} and \code{stateBias = 'derived'} become available, which instead force uncertain node
@@ -82,9 +82,9 @@
 #' 
 #' # let's write a quick&dirty ancestral trait plotting function
 #' 
-#'  quickAncPlot<-function(tree,trait,cex,orderedChar=FALSE,type="MPR",cost=NULL){
-#' 	ancData<-ancPropStateMat(tree=tree, trait=trait, orderedChar=orderedChar)
-#' 	ancCol<-(1:ncol(ancData))+1
+#' quickAncPlot<-function(tree, trait, cex, orderedChar=FALSE, type="MPR", cost=NULL){
+#' 	 ancData<-ancPropStateMat(tree=tree, trait=trait, orderedChar=orderedChar)
+#' 	 ancCol<-(1:ncol(ancData))+1
 #'  	plot(tree,show.tip.label=FALSE,no.margin=TRUE,direction="upwards")
 #'  	tiplabels(pch=16,pie=ancData[(1:Ntip(tree)),],cex=cex,piecol=ancCol,
 #' 		col=0)
@@ -107,8 +107,6 @@
 #' treeOrd<-resolveTreeChar(tree,trait,orderedChar=TRUE,stateBias=NULL)
 #' treeOrdPrim<-resolveTreeChar(tree,trait,orderedChar=TRUE,stateBias="primitive")
 #' treeOrdDer<-resolveTreeChar(tree,trait,orderedChar=TRUE,stateBias="derived")
-#' #and finally an unordered one with ACCTRAN
-#' treeACCTRAN<-resolveTreeChar(tree,trait,orderedChar=FALSE,type="ACCTRAN")
 #' 
 #' #compare number of nodes
 #' Nnode(tree)			#original
@@ -116,7 +114,6 @@
 #' Nnode(treeOrd)		#ordered, biasStates=NULL
 #' Nnode(treeOrdPrim)	#ordered, biasStates='primitive'
 #' Nnode(treeOrdDer)	#ordered, biasStates='derived'
-#' Nnode(treeACCTRAN)	#unordered, biasStates=NULL, ACCTRAN
 #' 
 #' #let's compare original tree with unordered-resolved tree
 #' layout(1:2)
@@ -150,12 +147,6 @@
 #' text(x=40,y=11,"orderedChar=TRUE",cex=1.5)
 #' text(x=40,y=4,"biasStates='primitive'",cex=1.5)
 #' 
-#' #let's compare unordered with MPR to unordered with ACCTRAN
-#' layout(1:2)
-#' quickAncPlot(treeUnord,trait,orderedChar=FALSE,type="MPR",cex=0.3)
-#' text(x=41,y=8,"unordered: MPR",cex=1.5)
-#' quickAncPlot(treeACCTRAN,trait,orderedChar=FALSE,type="ACCTRAN",cex=0.3)
-#' text(x=41,y=8,"unordered: ACCTRAN",cex=1.5)
 #' 
 #' #these comparisons will differ greatly between datasets
 #' 	# need to try them on your own
@@ -168,7 +159,7 @@
 #' @name resolveTreeChar
 #' @rdname resolveTreeChar
 #' @export
-resolveTreeChar<-function(tree, trait, orderedChar=FALSE, stateBias=NULL, iterative=TRUE, type="MPR", cost=NULL,
+resolveTreeChar<-function(tree, trait, orderedChar=FALSE, stateBias=NULL, iterative=TRUE, cost=NULL,
 			ambiguity= c(NA, "?"), dropAmbiguity=FALSE, polySymbol="&", contrast=NULL){
 		#	orderedChar=TRUE; type="MPR"; cost=NULL; stateBias="primitive"
 		#	orderedChar=FALSE; type="MPR"; cost=NULL; stateBias=NULL
@@ -197,7 +188,7 @@ resolveTreeChar<-function(tree, trait, orderedChar=FALSE, stateBias=NULL, iterat
 		tree2<-tree
 		continueRes<-TRUE
 		while(continueRes){
-			tree1<-resolveTreeCharMechanism(tree2, trait, orderedChar=orderedChar, stateBias=stateBias, type=type, cost=cost)
+			tree1<-resolveTreeCharMechanism(tree2, trait, orderedChar=orderedChar, stateBias=stateBias, type="MPR", cost=cost)
 			if(is.binary.tree(tree1) & is.rooted(tree1)){continueRes<-FALSE}
 			if(Nnode(tree1)==Nnode(tree2)){continueRes<-FALSE}
 			tree2<-tree1
@@ -205,13 +196,13 @@ resolveTreeChar<-function(tree, trait, orderedChar=FALSE, stateBias=NULL, iterat
 		treeFinal<-tree2
 	}else{
 		#only do it once
-		treeFinal<-resolveTreeCharMechanism(tree, trait, orderedChar=orderedChar, stateBias=stateBias, type=type, cost=cost)
+		treeFinal<-resolveTreeCharMechanism(tree, trait, orderedChar=orderedChar, stateBias=stateBias, type="MPR", cost=cost)
 		}
 	return(treeFinal)
 	}
 
 # internal function called by resolveTreeChar
-resolveTreeCharMechanism<-function(tree, trait, orderedChar, stateBias, type, cost){
+resolveTreeCharMechanism<-function(tree, trait, orderedChar, stateBias, type="MPR", cost){
 	nodeParts<-c(1:Ntip(tree),prop.part(tree))
 	#pick nodes based on being a polytomy
 	whichPoly<-sapply(1:max(tree$edge),function(x) sum(x==tree$edge[,1])>2)
