@@ -362,7 +362,7 @@
 #' Amniotes. \emph{Systematic Biology} 53(4):594-622.
 #' 
 #' Lloyd, G. T., S. C. Wang, and S. L. Brusatte. 2012 Identifying Heterogeneity
-#' in Rates of Morphological Evolutio: Discrete Character Change in the
+#' in Rates of Morphological Evolution: Discrete Character Change in the
 #' Evolution of Lungfish(Sarcopterygii, Dipnoi). \emph{Evolution}
 #' \bold{66}(2):330--348.
 #' 
@@ -808,7 +808,14 @@ bin_timePaleoPhy<-function(tree,timeList,type="basic",vartime=NULL,ntrees=1,
 			}
 		}	
 	timeList[[2]]<-timeList[[2]][!is.na(timeList[[2]][,1]),]
-	if(any(is.na(timeList[[2]]))){stop("Weird NAs in Data??")}
+	#
+	if(ncol(timeList[[1]])!=2 | ncol(timeList[[2]])!=2){
+		stop("Both timeList[[1]] and timeList[[2]] should have only two columns")}
+	if(any(is.na(timeList[[1]])) | any(is.na(timeList[[2]]))){
+		stop("Unexpected NAs in timeList")}
+	if(any(is.character(timeList[[1]])) | any(is.character(timeList[[2]]))){
+		stop("Unexpected character-type data in timeList")}
+	#
 	if(any(apply(timeList[[1]],1,diff)>0)){stop("timeList[[1]] not in intervals in time relative to modern")}
 	if(any(timeList[[1]][,2]<0)){stop("Some dates in timeList[[1]] <0 ?")}
 	if(any(apply(timeList[[2]],1,diff)<0)){stop("timeList[[2]] not in intervals numbered from first to last (1 to infinity)")}
